@@ -14,8 +14,8 @@ import (
 
 	"github.com/superfly/flyctl/flyctl"
 	"github.com/superfly/flyctl/internal/filemu"
+	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/internal/sentry"
-	"github.com/superfly/flyctl/logger"
 )
 
 type forkError struct{ error }
@@ -172,7 +172,7 @@ func createLogFile() (path string, err error) {
 func setupLogDirectory() (dir string, err error) {
 	dir = filepath.Join(flyctl.ConfigDir(), "agent-logs")
 
-	if err = os.MkdirAll(dir, 0700); err != nil {
+	if err = os.MkdirAll(dir, 0o700); err != nil {
 		err = fmt.Errorf("failed creating agent log directory at %s: %w", dir, err)
 
 		return
