@@ -145,10 +145,9 @@ func runMachineClone(ctx context.Context) (err error) {
 				fmt.Fprintf(out, "Volume '%s' will start empty\n", colorize.Bold(mnt.Name))
 			default:
 				snapshotID = &snapID
+				fmt.Fprintf(io.Out, "Creating new volume from snapshot: %s", colorize.Bold(*snapshotID))
 			}
 
-			fmt.Fprintf(io.Out, "Creating new volume from snapshot: %s", colorize.Bold(*snapshotID))
-
 			volInput := api.CreateVolumeInput{
 				AppID:             app.ID,
 				Name:              mnt.Name,
@@ -166,10 +165,8 @@ func runMachineClone(ctx context.Context) (err error) {
 
 		targetConfig.Mounts = []api.MachineMount{
 			{
-				Volume:    vol.ID,
-				Path:      mnt.Path,
-				SizeGb:    mnt.SizeGb,
-				Encrypted: mnt.Encrypted,
+				Volume: vol.ID,
+				Path:   mnt.Path,
 			},
 		}
 	}
